% Copyright (C) 2008 Medical College of Wisconsin.
% All rights reserved.
% 
% This software is distributed freely for academic and non-profit use. It
% should not be distributed or used for any commercial purpose without
% written permission from the Medical College of Wisconsin. For details
% please see User License Agreement.


% Adenylate Kinase (myokinase) (EC 2.7.4.3)
% 2·[ADP] <->  [ATP] + [AMP]
% A reaction, which helps to maintain levels of ATP during periods of stress or
% heightened metabolic challenge.

% Model generated from The Biochemical Simulation Environment (BISEN).

clear all;

%% Simulating Example 2
% (1.) Setting parameter values (no buffering)
B_X  = 0;      % Buffer capacity in both compartments
K_BX = 1e-7;   % Buffer dissoc. constant in both compartments
T = 25;        % Temperature

% (1.) Setting up Enzyme activities
par(1) = .1       % ATPase Activity

% (2.) Setting initial values
xo(1)  = 00e-3;     % ADP_cytoplasm
xo(2)  = 10e-3;      % ATP_cytoplasm
xo(3)  = 0;         % AMP_cytoplasm
xo(4)  = 1e-3;      % Pi_cytoplasm
xo(5) = 1e-7;       % [H] (M)
xo(6) = 1e-3;       % [Mg] (M)
xo(7) = 150e-3;     % [K] (M)

% (3.) Running for 15-second time course
[t,x] = ode23s(@Myokinase,[0 15],xo,[],T,B_X,K_BX,par);

% (4.) Plotting results
figure(1); p = plot(t,x(:,3)*1e3,'k-',t,x(:,1)*1e3,'k:',t,x(:,2)*1e3,'k--');
set(p,'linewidth',1.5);
text(2,9,'[ATP]','Fontsize',14);
text(2,2.6,'[ADP]','Fontsize',14);
text(2,.9,'[AMP]','Fontsize',14);
ylabel('Concentration (mM)','Fontsize',14);
xlabel('Time (sec)','Fontsize',14);
set(gca,'Fontsize',14);
figure(2); p = plot(t,-log10(x(:,5)),'k-','LineWidth',1.5);
ylabel('pH','Fontsize',14);
xlabel('Time (sec)','Fontsize',14);
set(gca,'Fontsize',14);

% Save to table:
Table = array2table([t,x],'variableNames',{'Time','BISEN_ADP','BISEN_ATP','BISEN_AMP','BISEN_PI','BISEN_H','BISEN_Mg','BISEN_K'});
S1 = 'MyoKBisenOutput';
S2 = '.csv';
filename1 = strcat(S1);  % Append runtime to filename
filename = strcat(filename1,S2);
%filename = 'MyoKBisenOutput.csv';
writetable(Table,filename);
%%
